@@ -33,6 +33,13 @@ from pyramid.response import Response
 from cardinal_pythonlib.httpconst import MimeType
 
 
+# =============================================================================
+# Character sets
+# =============================================================================
+
+UTF8 = "UTF-8"
+
+
 # =============================================================================
 # Responses
 # =============================================================================
@@ -63,6 +70,36 @@ class BinaryResponse(Response):
         )
 
 
+class JsonAttachmentResponse(Response):
+    """
+    Response class for returning a JSON file to the user as an attachment.
+    """
+    def __init__(self, body: str, filename: str, **kwargs) -> None:
+        super().__init__(
+            content_type=MimeType.JSON,
+            content_disposition=f"attachment; filename={filename}",
+            body=body,
+            charset=UTF8,
+            **kwargs
+        )
+
+
+class JsonResponse(Response):
+    """
+    Response class for showing JSON in the browser.
+    """
+    def __init__(self, body: str, **kwargs) -> None:
+        # Watch out here.
+        # TypeError: You cannot set the body to a text value without a charset
+        # https://github.com/Pylons/webob/issues/298
+        super().__init__(
+            content_type=MimeType.JSON,
+            body=body,
+            charset=UTF8,
+            **kwargs
+        )
+
+
 class OdsResponse(BinaryResponse):
     """
     Response class for returning an ODS (OpenOffice Spreadsheet) file to the
